classdef test_make_param_file < matlab.unittest.TestCase
    
    properties(TestParameter)
        params = {[1 1i],polysym([1 1i])};
        param_file_names = {'start_parameters','final_parameters'};
    end
    methods(TestMethodSetup)
        function setup(testCase)
            % Delete the input file, if it exists
            warning('off','MATLAB:DELETE:FileNotFound')
            delete(testCase.param_file_names{:});
            warning('on','MATLAB:DELETE:FileNotFound')
        end
    end
    
    methods(Test)
        function testNoData(testCase)
            obj = BertiniLab;
            f = @() make_param_file(obj);
            testCase.verifyError(f,'MATLAB:minrhs')
        end
        
        function testNoFileName(testCase)
            obj = BertiniLab;            
            f = @() make_param_file(obj,polysym(0));
            testCase.verifyError(f,'MATLAB:minrhs')
        end
        
        function testMinimalStart(testCase,params,param_file_names)    
            obj = BertiniLab;
            s = obj.make_param_file(params,param_file_names);
            testCase.verifyEqual(s,param_file_names)
            
            fid = fopen(param_file_names);
            n = fscanf(fid,'%d\n\n',1);
            testCase.verifyEqual(n,numel(params))
            x = fscanf(fid,'%d %d\n',[n n]);
            testCase.verifyEqual(x,[1 0; 0 1])
            fclose(fid);
        end
        
    end
    
    methods(TestMethodTeardown)
        function teardown(testCase)
            % Delete the input file, if it exists
            warning('off','MATLAB:DELETE:FileNotFound')
            delete(testCase.param_file_names{:});
            warning('on','MATLAB:DELETE:FileNotFound')
        end
    end
end
