classdef test_struct2mat < matlab.unittest.TestCase
    
    properties (TestParameter)
        input_file_fun = {@(x) x,@(x) make_input_file(x)};
        xsols = {[1 -1],polysym([1 -1]),{1,-1}};
        xsols_struct = {struct('x',[1 -1]), struct('x',polysym([1 -1]))};
    end
    methods(Test)
        function testEmpty(testCase)
            obj = BertiniLab;
            sols = struct.empty;
            f = @() obj.struct2mat(sols);
            testCase.verifyError(f,'BertiniLab:struct2mat:noVariables')
        end
        function testOneVariableRowVectorInput(testCase,input_file_fun,xsols)
            obj = BertiniLab;
            obj.variable_group = 'x';
            obj.function_def = 'x^2-1';
            obj = input_file_fun(obj);
            M = obj.struct2mat(xsols);
            testCase.verifyEqual(M,polysym(xsols(:).'))
        end
        function testOneVariableRowVectorInputSym(testCase,input_file_fun)
            % Test only if the Symbolic Toolbox is installed; otherwise
            % fail by verification
            testCase.assumeNotEmpty(ver('symbolic'))
            obj = BertiniLab;
            obj.variable_group = 'x';
            obj.function_def = 'x^2-1';
            obj = input_file_fun(obj);
            sols = sym([1 -1]);
            M = obj.struct2mat(sols);
            testCase.verifyEqual(M,polysym(sols(:).'))
        end
        function testScalarVariableColumnVectorInput(testCase,input_file_fun,xsols)
            % A column vector is interpreted as one solution with multiple
            % variables.
            obj = BertiniLab;
            obj.variable_group = 'x';
            obj.function_def = 'x^2-1';
            obj = input_file_fun(obj);
            f = @() obj.struct2mat(xsols.');
            testCase.verifyError(f,'BertiniLab:struct2mat:wrongLength')
        end
        function testOneVariableStructInput(testCase,input_file_fun,xsols_struct)
            obj = BertiniLab;
            obj.variable_group = 'x';
            obj.function_def = 'x^2-1';
            obj = input_file_fun(obj);
            M = obj.struct2mat(xsols_struct);
            testCase.verifyEqual(M,polysym(xsols_struct.x(:).'))
        end
        function testOneVariableInvalidInput(testCase,input_file_fun)
            obj = BertiniLab;
            obj.variable_group = 'x';
            obj.function_def = 'x^2-1';
            obj = input_file_fun(obj);
            sols = true;
            f = @() obj.struct2mat(sols);
            testCase.verifyError(f,'MATLAB:polysym:invalidType')
        end
        function testOneVariableNonmatchingFieldNames(testCase,input_file_fun)
            obj = BertiniLab;
            obj.variable_group = 'x';
            obj.function_def = 'x^2-1';
            obj = input_file_fun(obj);
            sols = struct('y',[1 -1]);
            f = @() obj.struct2mat(sols);
            testCase.verifyError(f,'BertiniLab:struct2mat:mismatched')
        end
        function testVectorVariable(testCase,input_file_fun)
            polysyms mu0 lambda
            v = polysym('v',[1 2]);
            vars = {[mu0 lambda],v};
            A = [1 2; 2 4]; B = [4 -2; -2 1];
            eqns = mu0*A*v.' - lambda*B*v.';
            
            obj = BertiniLab;
            obj.function_def=eqns;
            obj.hom_variable_group=vars;
            obj = input_file_fun(obj);
            
            sols = struct('mu0',randi(100,1),'lambda',randi(100,1),'v',randi(100,1,2));
            actual = obj.struct2mat(sols);
            expected = polysym([sols.mu0; sols.lambda; sols.v.']);
            testCase.verifyEqual(actual,expected)
        end
    end
    
    methods(TestMethodTeardown)
        function teardown(~)
            BertiniClean
        end
    end
end